
[![codecov](https://codecov.io/github/tzoght/fundaml/branch/main/graph/badge.svg?token=UB03POGOUB)](https://codecov.io/github/tzoght/fundaml)
[![ci-cd](https://github.com/tzoght/fundaml/actions/workflows/ci-cd.yml/badge.svg?branch=main)](https://github.com/tzoght/fundaml/actions/workflows/ci-cd.yml) [![Documentation Status](https://readthedocs.org/projects/fundaml/badge/?version=latest)](https://fundaml.readthedocs.io/en/stable/?badge=stable) ![PyPI](https://img.shields.io/pypi/v/fundaml)

# fundaml

The purpose of this module is simply to simplify ML learning and use best practices while developing ML models. 

**Standardization**: The fundaml project is an attempt to standardize the way ML projects are structured within a team or organization, promoting best practices for organization, testing, and documentation.

**Flexibility**: fundaml is designed with flexibility in mind. Users can likely use different parts of the codebase as needed, and extend or modify components to suit their specific requirements.

**Extensibility**: fundaml could be used as a starting point for building more complex, domain-specific machine learning libraries. The name fundaml itself is intended to be a "**base**" or foundation upon which other things can be built.


## Installation

```bash
$ pip install fundaml
```
from  [Pypi repo](https://pypi.org/project/fundaml)

## Developers

Please visit [DEVELOPERS.md](https://github.com/tzoght/fundaml/blob/main/DEVELOPERS.md) to set the module for contribution 

## Usage

See [docs](https://github.com/tzoght/fundaml/blob/main/docs/example.ipynb)

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`fundaml` was created by Tony Zoght. It is licensed under the terms of the MIT license.

## Credits

`fundaml` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).


## Code Coverage
* [CodeCov](https://app.codecov.io/github/tzoght/fundaml) 

## Read The Docs
https://fundaml.readthedocs.io/en/latest/?badge=latest

## Github Pages
https://tzoght.github.io/fundaml/

